<?php
/**
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace OCA\SideMenu\Controller;

use OCP\AppFramework\Controller;
use OCP\AppFramework\Http\TemplateResponse;
use OCP\AppFramework\Http\Response;
use OCP\IConfig;
use OCP\IRequest;

class JsController extends Controller
{

    /**
     * @var \OCP\IConfig
     */
    protected $config;

    /**
     * @param string $appName
     * @param IRequest $request
     * @param IConfig $config
     */
    public function __construct($appName, IRequest $request, IConfig $config)
    {
        parent::__construct($appName, $request);

        $this->config = $config;
    }

    /**
     * @NoAdminRequired
     * @NoCSRFRequired
     * @PublicPage
     *
     * @return Response
     */
    public function script()
    {
        $parameters = [
            'opener-position' => $this->config->getAppValue('side_menu', 'opener-position', 'before'),
            'opener-hover' => (bool) $this->config->getAppValue('side_menu', 'opener-hover', '0'),
            'external-sites-in-top-menu' => (bool) $this->config->getAppValue('side_menu', 'external-sites-in-top-menu', 0),
            'force-light-icon' => (bool) $this->config->getAppValue('side_menu', 'force-light-icon', '0'),
            'hide-when-no-apps' => (bool) $this->config->getAppValue('side_menu', 'hide-when-no-apps', '0'),
            'loader-enabled' => (bool) $this->config->getAppValue('side_menu', 'loader-enabled', '1'),
        ];

        $response = new TemplateResponse('side_menu', 'js/script', $parameters, 'blank');
        $response->addHeader('Content-Type', 'text/javascript');

        return $response;
    }
}
