<?php
/**
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace OCA\SideMenu\Settings;

use OCP\AppFramework\Http\TemplateResponse;
use OCP\IL10N;
use OCP\ILogger;
use OCP\Settings\ISettings;
use OCP\IConfig;

class Admin implements ISettings
{
    /**
     * @var IL10N
     */
    private $l;

    /**
     * @var ILogger
     */
    private $logger;

    /**
     * @var IConfig
     */
    private $config;

    public function __construct(IL10N $l, ILogger $logger, IConfig $config)
    {
        $this->l = $l;
        $this->logger = $logger;
        $this->config = $config;
    }

    /**
     * @return TemplateResponse
     */
    public function getForm()
    {
        $backgroundColor = $this->config->getAppValue('side_menu', 'background-color', '#333333');
        $backgroundColorTo = $this->config->getAppValue('side_menu', 'background-color-to', $backgroundColor);

        $parameters = [
            'background-color' => $backgroundColor,
            'background-color-to' => $backgroundColorTo,
            'current-app-background-color' => $this->config->getAppValue('side_menu', 'current-app-background-color', '#444444'),
            'loader-color' => $this->config->getAppValue('side_menu', 'loader-color', '#0e75ac'),
            'loader-enabled' => $this->config->getAppValue('side_menu', 'loader-enabled', '1'),
            'text-color' => $this->config->getAppValue('side_menu', 'text-color', '#FFFFFF'),
            'force-light-icon' => $this->config->getAppValue('side_menu', 'force-light-icon', '0'),
            'cache' => $this->config->getAppValue('side_menu', 'cache', '0'),
            'opener' => $this->config->getAppValue('side_menu', 'opener', 'side-menu-opener'),
            'display-logo' => $this->config->getAppValue('side_menu', 'display-logo', '1'),
            'opener-position' => $this->config->getAppValue('side_menu', 'opener-position', 'before'),
            'opener-hover' => $this->config->getAppValue('side_menu', 'opener-hover', '0'),
            'opener-only' => $this->config->getAppValue('side_menu', 'opener-only', '0'),
            'hide-when-no-apps' => $this->config->getAppValue('side_menu', 'hide-when-no-apps', '0'),
            'size-icon' => $this->config->getAppValue('side_menu', 'size-icon', 'normal'),
            'size-text' => $this->config->getAppValue('side_menu', 'size-text', 'normal'),
            'external-sites-in-top-menu' => $this->config->getAppValue('side_menu', 'external-sites-in-top-menu', '0'),
        ];

        return new TemplateResponse('side_menu', 'settings/admin-form', $parameters, '');
    }

    /**
     * @return string the section ID, e.g. 'sharing'
     */
    public function getSection()
    {
        return 'side_menu';
    }

    /**
     * @return int whether the form should be rather on the top or bottom of
     * the admin section. The forms are arranged in ascending order of the
     * priority values. It is required to return a value between 0 and 100.
     *
     * E.g.: 70
     */
    public function getPriority()
    {
        return 70;
    }
}
